# crashlog 0.1.0

Send email and log to file when there's an uncaught exception in your code


# Install

    pip install crashlog


# Usage
    
    import crashlog

    crashlog.install(email=['bugs@looney.org'], logfile='/path/to/log.txt')

Contact
=======
Miki Tebeka <miki.tebeka@gmail.com>

Bug reports go [here][bugs].


[bugs]: https://bitbucket.org/tebeka/crashlog/issues
